aboutsummaryrefslogtreecommitdiffstats
path: root/bin
diff options
context:
space:
mode:
Diffstat (limited to 'bin')
-rw-r--r--bin/pick/ui.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/bin/pick/ui.py b/bin/pick/ui.py
index 2d7b510703f..3afd05e0ca2 100644
--- a/bin/pick/ui.py
+++ b/bin/pick/ui.py
@@ -240,8 +240,8 @@ class UI:
{err}
- You can either cancel, or resolve the conflicts, commit the
- changes and select ok."""))
+ You can either cancel, or resolve the conflicts (`git mergetool`), finish the
+ cherry-pick (`git cherry-pick --continue`) and select ok."""))
can_btn = urwid.Button('Cancel')
urwid.connect_signal(can_btn, 'click', reset_cb)